/*
 * $Id: AddReceivedNodeService.java 22334 2011-07-06 06:52:14Z claude.mamo $
 * --------------------------------------------------------------------------------------
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 *
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */

package org.mule.test.integration.routing.outbound;

import org.dom4j.Document;

/**
 * TODO
 */
public class AddReceivedNodeService
{
    public Document addNodeTo(Document doc)
    {
        doc.getRootElement().addElement("Received");

        return doc;
    }
}
